@@ -51,22 +51,28 @@ class BaseMenu:
         Manages gathering user input, basic validation, sending messages, and cancellation requests."""
         pass
 
-    async def next(self, name: str = None):
+    async def next(self, name: Optional[Union[str, int]] = None):
         """Sets a specific :class:`~dpymenus.Page` to go to and calls the :func:`~send_message()` method to display the embed.
 
-        :param name: A specific page object name. If this is not set, the next page in the list will be called.
+        :param name: A specific page object name or its index. If this is not set, the next page in the list will be called.
         """
         if name is None:
             self.page_index += 1
             self.page = self.pages[self.page_index]
 
         else:
-            # get a page index from its on_next callback function name and assign it
-            for page in self.pages:
-                if page.on_next.__name__ == name:
-                    self.page_index = self.pages.index(page)
-                    self.page = self.pages[self.page_index]
-                    break
+            if isinstance(name, str):
+                # get a page index from its on_next callback function name and assign it
+                for page in self.pages:
+                    if page.on_next.__name__ == name:
+                        self.page_index = self.pages.index(page)
+                        self.page = self.pages[self.page_index]
+                        break
+
+            elif isinstance(name, int):
+                # get a page index from its index and assign it
+                self.page_index = name
+                self.page = self.pages[name]
 
         #  if the next page has no on_next callback, we end the menu loop
         if self.page.on_next is None:
@@ -74,6 +80,13 @@ class BaseMenu:
 
         await self.send_message(self.page)
 
+    async def previous(self):
+        """Helper method for quickly accessing the previous page."""
+        self.page_index -= 1
+        self.page = self.pages[self.page_index]
+
+        await self.send_message(self.page)
+
     async def add_page(self, on_next: Optional[Callable] = None, buttons: Optional[List[Union[str, Emoji, PartialEmoji]]] = None, **kwargs) -> Page:
         """Adds a new page object to the Menu.
 
@@ -111,7 +124,7 @@ class BaseMenu:
         if self.page.on_cancel:
             return await self.page.on_cancel()
 
-        embed = Embed(title=self.page.title, description='Menu selection cancelled -- no progress was saved.', color=Colour.red())
+        embed = Embed(title=self.page.title, description='Menu selection cancelled.', color=Colour.red())
         await self.send_message(embed)
         self.active = False
 
@@ -132,7 +145,7 @@ class BaseMenu:
         if self.page.on_timeout:
             return await self.page.on_timeout()
 
-        embed = Embed(title=self.page.title, description='You timed out at menu selection -- no progress was saved.', color=Colour.red())
+        embed = Embed(title=self.page.title, description='You timed out at menu selection.', color=Colour.red())
         await self.send_message(embed)
 
     async def _is_cancelled(self) -> bool:
